@@ -1,7 +1,9 @@
 mod utils;
 
 pub mod application;
+pub mod archive;
 pub mod build_system;
 pub mod filename;
+pub mod format;
 pub mod module;
 pub mod source;
